Live settings — Askbot v0.7.43 documentation

# Askbot Project Documentation

Home | Ask Questions | Hire Us | Documentation | Contribute | Contact

# Live settings

Many of the configuration settings in askbot are accessible to the site administators via link “settings” in the site header.

Any change to the “live settings” will be reflected on the site immediately.

No-one but the site administrators can change those settings.

Note

Any user can be turned into an administrator via running a command.

> python manage.py add_admin <user_id>

At the moment this command is not available from the web-interface but this will be fixed in the future.